@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "parrot" "1.2.0"
+(define-package "parrot" "20260111.2133"
   "Party Parrot rotates gracefully in the mode-line."
   '((emacs "24.1"))
   :url "https://github.com/dp12/parrot.git"
